Learn R Programming

panp (version 1.42.0)

NSMPnames.hgu133plus2: Negative Strand Matching Probeset (NSMP) names for HG-U133 Plus 2.0 chip type

Description

This list of NSMP probeset names is used by pa.calls() in calculating the NSMP expression distribution. It is specific to the chip type; the correct version is automatically loaded for the detected chip type, if supported. The user does not load or use this data directly.

Usage

data(NSMPnames.hgu133plus2)

Arguments

Format

A vector containing probeset names

October 2004 AffyMetrix chip annotation files, filtered, with outliers removed